@@ -579,7 +579,8 @@ def test_new_latex_stage(tmp_dir):
     pipeline = calkit.dvc.read_pipeline()
     assert pipeline["stages"]["build-paper"]["cmd"] == (
         "calkit xenv -n tex --no-check -- "
-        "latexmk -cd -interaction=nonstopmode -silent -synctex=1 -pdf paper.tex"
+        "latexmk -cd -norc -interaction=nonstopmode -silent -synctex=1 "
+        "-pdf paper.tex"
     )
     assert set(pipeline["stages"]["build-paper"]["deps"]) == set(
         ["paper.tex", ".calkit/env-locks/tex.json"]
@@ -649,6 +650,8 @@ def test_new_julia_env(tmp_dir):
             "julia-env",
             "--name",
             "j2",
+            "--julia",
+            "1.10",
             "Revise",
             "--path",
             "envs/my-env/Project.toml",
